@@ -5,7 +5,7 @@ BEGIN {
   $BenchmarkAnything::Storage::Frontend::HTTP::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Access a BenchmarkAnything store via HTTP
-$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.005';
+$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.006';
 use Mojo::Base 'Mojolicious';
 
 require BenchmarkAnything::Storage::Frontend::Lib;
@@ -23,10 +23,10 @@ sub startup {
         my $self = shift;
 
         $self->log->debug("Using BenchmarkAnything");
-        $self->log->debug(" - Configfile: ".$balib->{cfgfile});
+        $self->log->debug(" - Configfile: ".$balib->{config}{cfgfile});
         $self->log->debug(" - Backend:    ".$balib->{config}{benchmarkanything}{backend});
         $self->log->debug(" - DSN:        ".$balib->{config}{benchmarkanything}{storage}{backend}{sql}{dsn});
-        die "Config backend:".$balib->{config}{benchmarkanything}{backend}."' not yet supported (".$balib->{cfgfile}."), must be 'local'.\n"
+        die "Config backend:".$balib->{config}{benchmarkanything}{backend}."' not yet supported (".$balib->{config}{cfgfile}."), must be 'local'.\n"
          if $balib->{config}{benchmarkanything}{backend} ne 'local';
 
         my $queueing_processing_batch_size = $balib->{config}{benchmarkanything}{storage}{backend}{sql}{queueing}{processing_batch_size} || 100;
